Class: Google::Apis::DatafusionV1beta1::DataFusionService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::DatafusionV1beta1::DataFusionService
- Defined in:
- lib/google/apis/datafusion_v1beta1/service.rb
Overview
Cloud Data Fusion API
Cloud Data Fusion is a fully-managed, cloud native, enterprise data integration service for quickly building and managing data pipelines. It provides a graphical interface to increase time efficiency and reduce complexity, and allows business users, developers, and data scientists to easily and reliably build scalable data integration solutions to cleanse, prepare, blend, transfer and transform data without having to wrestle with infrastructure.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://datafusion.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Creates a new Data Fusion instance in the specified project and location.
-
#create_project_location_instance_dns_peering(parent, dns_peering_object = nil, dns_peering_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::DnsPeering
Creates DNS peering on the given resource.
-
#delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Deletes a single Data Fusion instance.
-
#delete_project_location_instance_dns_peering(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Empty
Deletes DNS peering on the given resource.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Location
Gets information about a location.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Instance
Gets details of a single Data Fusion instance.
-
#get_project_location_instance_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Gets the access control policy for a resource.
-
#get_project_location_instance_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ DataFusionService
constructor
A new instance of DataFusionService.
-
#list_project_location_instance_dns_peerings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListDnsPeeringsResponse
Lists DNS peerings for a given resource.
-
#list_project_location_instance_namespaces(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListNamespacesResponse
List namespaces in a given instance.
-
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListInstancesResponse
Lists Data Fusion instances in the specified project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_location_versions(parent, latest_patch_only: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListAvailableVersionsResponse
Lists possible versions for Data Fusion instances in the specified project and location.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Updates a single Data Fusion instance.
-
#remove_location_iam_policy(resource, remove_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::RemoveIamPolicyResponse
Remove IAM policy that is currently set on the given resource.
-
#restart_instance(name, restart_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Restart a single Data Fusion instance.
-
#set_instance_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Sets the access control policy on the specified resource.
-
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Sets the access control policy on the specified resource.
-
#test_instance_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Upgrade a single Data Fusion instance.
Constructor Details
#initialize ⇒ DataFusionService
Returns a new instance of DataFusionService.
53 54 55 56 57 58 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 53 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-datafusion_v1beta1', client_version: Google::Apis::DatafusionV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
46 47 48 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 46 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
51 52 53 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 51 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
862 863 864 865 866 867 868 869 870 871 872 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 862 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:cancel', ) command.request_representation = Google::Apis::DatafusionV1beta1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::DatafusionV1beta1::Empty::Representation command.response_class = Google::Apis::DatafusionV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Creates a new Data Fusion instance in the specified project and location.
205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 205 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/instances', ) command.request_representation = Google::Apis::DatafusionV1beta1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::DatafusionV1beta1::Operation::Representation command.response_class = Google::Apis::DatafusionV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance_dns_peering(parent, dns_peering_object = nil, dns_peering_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::DnsPeering
Creates DNS peering on the given resource.
586 587 588 589 590 591 592 593 594 595 596 597 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 586 def create_project_location_instance_dns_peering(parent, dns_peering_object = nil, dns_peering_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/dnsPeerings', ) command.request_representation = Google::Apis::DatafusionV1beta1::DnsPeering::Representation command.request_object = dns_peering_object command.response_representation = Google::Apis::DatafusionV1beta1::DnsPeering::Representation command.response_class = Google::Apis::DatafusionV1beta1::DnsPeering command.params['parent'] = parent unless parent.nil? command.query['dnsPeeringId'] = dns_peering_id unless dns_peering_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Deletes a single Data Fusion instance.
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 242 def delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DatafusionV1beta1::Operation::Representation command.response_class = Google::Apis::DatafusionV1beta1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance_dns_peering(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Empty
Deletes DNS peering on the given resource.
620 621 622 623 624 625 626 627 628 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 620 def delete_project_location_instance_dns_peering(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DatafusionV1beta1::Empty::Representation command.response_class = Google::Apis::DatafusionV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
897 898 899 900 901 902 903 904 905 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 897 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DatafusionV1beta1::Empty::Representation command.response_class = Google::Apis::DatafusionV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Location
Gets information about a location.
80 81 82 83 84 85 86 87 88 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 80 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DatafusionV1beta1::Location::Representation command.response_class = Google::Apis::DatafusionV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Instance
Gets details of a single Data Fusion instance.
274 275 276 277 278 279 280 281 282 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 274 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DatafusionV1beta1::Instance::Representation command.response_class = Google::Apis::DatafusionV1beta1::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
318 319 320 321 322 323 324 325 326 327 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 318 def get_project_location_instance_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::DatafusionV1beta1::Policy::Representation command.response_class = Google::Apis::DatafusionV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
705 706 707 708 709 710 711 712 713 714 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 705 def get_project_location_instance_namespace_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::DatafusionV1beta1::Policy::Representation command.response_class = Google::Apis::DatafusionV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
928 929 930 931 932 933 934 935 936 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 928 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::DatafusionV1beta1::Operation::Representation command.response_class = Google::Apis::DatafusionV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_dns_peerings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListDnsPeeringsResponse
Lists DNS peerings for a given resource.
659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 659 def list_project_location_instance_dns_peerings(parent, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/dnsPeerings', ) command.response_representation = Google::Apis::DatafusionV1beta1::ListDnsPeeringsResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::ListDnsPeeringsResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_namespaces(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListNamespacesResponse
List namespaces in a given instance
745 746 747 748 749 750 751 752 753 754 755 756 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 745 def list_project_location_instance_namespaces(parent, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/namespaces', ) command.response_representation = Google::Apis::DatafusionV1beta1::ListNamespacesResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::ListNamespacesResponse command.params['parent'] = parent unless parent.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListInstancesResponse
Lists Data Fusion instances in the specified project and location.
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 361 def list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/instances', ) command.response_representation = Google::Apis::DatafusionV1beta1::ListInstancesResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
973 974 975 976 977 978 979 980 981 982 983 984 985 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 973 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::DatafusionV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_versions(parent, latest_patch_only: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListAvailableVersionsResponse
Lists possible versions for Data Fusion instances in the specified project and location.
1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 1018 def list_project_location_versions(parent, latest_patch_only: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/versions', ) command.response_representation = Google::Apis::DatafusionV1beta1::ListAvailableVersionsResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::ListAvailableVersionsResponse command.params['parent'] = parent unless parent.nil? command.query['latestPatchOnly'] = latest_patch_only unless latest_patch_only.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 132 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::DatafusionV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Updates a single Data Fusion instance.
403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 403 def patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::DatafusionV1beta1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::DatafusionV1beta1::Operation::Representation command.response_class = Google::Apis::DatafusionV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#remove_location_iam_policy(resource, remove_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::RemoveIamPolicyResponse
Remove IAM policy that is currently set on the given resource.
167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 167 def remove_location_iam_policy(resource, remove_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:removeIamPolicy', ) command.request_representation = Google::Apis::DatafusionV1beta1::RemoveIamPolicyRequest::Representation command.request_object = remove_iam_policy_request_object command.response_representation = Google::Apis::DatafusionV1beta1::RemoveIamPolicyResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::RemoveIamPolicyResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#restart_instance(name, restart_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Restart a single Data Fusion instance. At the end of an operation instance is fully restarted.
439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 439 def restart_instance(name, restart_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:restart', ) command.request_representation = Google::Apis::DatafusionV1beta1::RestartInstanceRequest::Representation command.request_object = restart_instance_request_object command.response_representation = Google::Apis::DatafusionV1beta1::Operation::Representation command.response_class = Google::Apis::DatafusionV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_instance_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 476 def set_instance_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::DatafusionV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::DatafusionV1beta1::Policy::Representation command.response_class = Google::Apis::DatafusionV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
783 784 785 786 787 788 789 790 791 792 793 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 783 def set_namespace_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::DatafusionV1beta1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::DatafusionV1beta1::Policy::Representation command.response_class = Google::Apis::DatafusionV1beta1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_instance_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
515 516 517 518 519 520 521 522 523 524 525 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 515 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::DatafusionV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_namespace_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
822 823 824 825 826 827 828 829 830 831 832 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 822 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::DatafusionV1beta1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::DatafusionV1beta1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::DatafusionV1beta1::Operation
Upgrade a single Data Fusion instance. At the end of an operation instance is fully upgraded.
551 552 553 554 555 556 557 558 559 560 561 |
# File 'lib/google/apis/datafusion_v1beta1/service.rb', line 551 def upgrade_instance(name, upgrade_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:upgrade', ) command.request_representation = Google::Apis::DatafusionV1beta1::UpgradeInstanceRequest::Representation command.request_object = upgrade_instance_request_object command.response_representation = Google::Apis::DatafusionV1beta1::Operation::Representation command.response_class = Google::Apis::DatafusionV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |