Class: Google::Apis::DatafusionV1beta1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datafusion_v1beta1/classes.rb,
lib/google/apis/datafusion_v1beta1/representations.rb,
lib/google/apis/datafusion_v1beta1/representations.rb

Overview

Represents the metadata of a long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



1282
1283
1284
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_statusHash<String,String>

Map to hold any additional status info for the operation If there is an accelerator being enabled/disabled/deleted, this will be populated with accelerator name as key and status as ENABLING, DISABLING or DELETING Corresponds to the JSON property additionalStatus

Returns:

  • (Hash<String,String>)


1242
1243
1244
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1242

def additional_status
  @additional_status
end

#api_versionString

API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


1247
1248
1249
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1247

def api_version
  @api_version
end

#create_timeString

The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


1252
1253
1254
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1252

def create_time
  @create_time
end

#end_timeString

The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


1257
1258
1259
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1257

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


1264
1265
1266
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1264

def requested_cancellation
  @requested_cancellation
end

#status_detailString

Human-readable status of the operation if any. Corresponds to the JSON property statusDetail

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1270

def status_detail
  @status_detail
end

#targetString

Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1275

def target
  @target
end

#verbString

Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1280

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1287

def update!(**args)
  @additional_status = args[:additional_status] if args.key?(:additional_status)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end