Class: Google::Apis::DatafusionV1beta1::PrivateServiceConnectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/datafusion_v1beta1/classes.rb,
lib/google/apis/datafusion_v1beta1/representations.rb,
lib/google/apis/datafusion_v1beta1/representations.rb

Overview

Configuration for using Private Service Connect to establish connectivity between the Data Fusion consumer project and the corresponding tenant project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateServiceConnectConfig

Returns a new instance of PrivateServiceConnectConfig.



1416
1417
1418
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1416

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_unreachable_cidr_blockString

Output only. The CIDR block to which the CDF instance can't route traffic to in the consumer project VPC. The size of this block is /25. The format of this field is governed by RFC 4632. Example: 240.0.0.0/25 Corresponds to the JSON property effectiveUnreachableCidrBlock

Returns:

  • (String)


1395
1396
1397
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1395

def effective_unreachable_cidr_block
  @effective_unreachable_cidr_block
end

#network_attachmentString

Required. The reference to the network attachment used to establish private connectivity. It will be of the form projects/project-id/regions/region/ networkAttachments/network-attachment-id. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


1402
1403
1404
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1402

def network_attachment
  @network_attachment
end

#unreachable_cidr_blockString

Optional. Input only. The CIDR block to which the CDF instance can't route traffic to in the consumer project VPC. The size of this block should be at least /25. This range should not overlap with the primary address range of any subnetwork used by the network attachment. This range can be used for other purposes in the consumer VPC as long as there is no requirement for CDF to reach destinations using these addresses. If this value is not provided, the server chooses a non RFC 1918 address range. The format of this field is governed by RFC 4632. Example: 192.168.0.0/25 Corresponds to the JSON property unreachableCidrBlock

Returns:

  • (String)


1414
1415
1416
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1414

def unreachable_cidr_block
  @unreachable_cidr_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1421
1422
1423
1424
1425
# File 'lib/google/apis/datafusion_v1beta1/classes.rb', line 1421

def update!(**args)
  @effective_unreachable_cidr_block = args[:effective_unreachable_cidr_block] if args.key?(:effective_unreachable_cidr_block)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
  @unreachable_cidr_block = args[:unreachable_cidr_block] if args.key?(:unreachable_cidr_block)
end